==> qtjambi-remoteobjects-jre8-5.15.5-sources.jar: io/qt/remoteobjects/QAbstractItemModelReplica.java <==
package io.qt.remoteobjects;


/**
 * <p>Java wrapper for Qt class QAbstractItemModelReplica</p>
 */
public final class QAbstractItemModelReplica extends io.qt.core.QAbstractItemModel
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractItemModelReplica.class);
    

    public final Signal0 initialized = new Signal0();
    
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<java.lang.Integer> availableRoles(){
        return availableRoles_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<java.lang.Integer> availableRoles_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasData(io.qt.core.QModelIndex index, int role){
        return hasData_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index, role);
    }
    
    @io.qt.QtUninvokable
    private native boolean hasData_native_cref_QModelIndex_int_constfct(long __this__nativeId, io.qt.core.QModelIndex index, int role);
    
    @io.qt.QtUninvokable
    public final boolean isInitialized(){
        return isInitialized_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isInitialized_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final long rootCacheSize(){
        return rootCacheSize_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native long rootCacheSize_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QItemSelectionModel selectionModel(){
        return selectionModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QItemSelectionModel selectionModel_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setRootCacheSize(long rootCacheSize){
        setRootCacheSize_native_size_t(QtJambi_LibraryUtilities.internal.nativeId(this), rootCacheSize);
    }
    
    @io.qt.QtUninvokable
    private native void setRootCacheSize_native_size_t(long __this__nativeId, long rootCacheSize);
    
    @io.qt.QtUninvokable
    public int columnCount(io.qt.core.QModelIndex parent){
        return columnCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), parent);
    }
    
    @io.qt.QtUninvokable
    private native int columnCount_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex parent);
    
    @io.qt.QtUninvokable
    public java.lang.Object data(io.qt.core.QModelIndex index, int role){
        return data_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index, role);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object data_native_cref_QModelIndex_int_constfct(long __this__nativeId, io.qt.core.QModelIndex index, int role);
    
    @io.qt.QtUninvokable
    public io.qt.core.Qt.ItemFlags flags(io.qt.core.QModelIndex index){
        return new io.qt.core.Qt.ItemFlags(flags_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index));
    }
    
    @io.qt.QtUninvokable
    private native int flags_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex index);
    
    @io.qt.QtUninvokable
    public boolean hasChildren(io.qt.core.QModelIndex parent){
        return hasChildren_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), parent);
    }
    
    @io.qt.QtUninvokable
    private native boolean hasChildren_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex parent);
    
    @io.qt.QtUninvokable
    public java.lang.Object headerData(int section, io.qt.core.Qt.Orientation orientation, int role){
        return headerData_native_int_Qt_Orientation_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), section, orientation.value(), role);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object headerData_native_int_Qt_Orientation_int_constfct(long __this__nativeId, int section, int orientation, int role);
    
    @io.qt.QtUninvokable
    public io.qt.core.QModelIndex index(int row, int column, io.qt.core.QModelIndex parent){
        return index_native_int_int_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), row, column, parent);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex index_native_int_int_cref_QModelIndex_constfct(long __this__nativeId, int row, int column, io.qt.core.QModelIndex parent);
    
    @io.qt.QtUninvokable
    public io.qt.core.QModelIndex parent(io.qt.core.QModelIndex index){
        return parent_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex parent_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex index);
    
    @io.qt.QtUninvokable
    public java.util.Map<java.lang.Integer, io.qt.core.QByteArray> roleNames(){
        return roleNames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.util.Map<java.lang.Integer, io.qt.core.QByteArray> roleNames_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public int rowCount(io.qt.core.QModelIndex parent){
        return rowCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), parent);
    }
    
    @io.qt.QtUninvokable
    private native int rowCount_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex parent);
    
    @io.qt.QtUninvokable
    public boolean setData(io.qt.core.QModelIndex index, java.lang.Object value, int role){
        return setData_native_cref_QModelIndex_cref_QVariant_int(QtJambi_LibraryUtilities.internal.nativeId(this), index, value, role);
    }
    
    @io.qt.QtUninvokable
    private native boolean setData_native_cref_QModelIndex_cref_QVariant_int(long __this__nativeId, io.qt.core.QModelIndex index, java.lang.Object value, int role);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractItemModelReplica(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-remoteobjects-jre8-6.2.3-sources.jar: io/qt/remoteobjects/QAbstractItemModelReplica.java <==
package io.qt.remoteobjects;


/**
 * <p>Serves as a convenience class for Replicas of Sources based on QAbstractItemModel</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qabstractitemmodelreplica.html">QAbstractItemModelReplica</a></p>
 */
public final class QAbstractItemModelReplica extends io.qt.core.QAbstractItemModel
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractItemModelReplica.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodelreplica.html#initialized">QAbstractItemModelReplica::initialized()</a></p>
     */
    public final Signal0 initialized = new Signal0();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodelreplica.html#availableRoles">QAbstractItemModelReplica::availableRoles()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<java.lang.Integer> availableRoles(){
        return availableRoles_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Integer> availableRoles_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#data">QAbstractItemModel::data(QModelIndex,int)const</a></p>
     */
    public final java.lang.Object data(io.qt.core.QModelIndex index, int role){
        return data_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index, role);
    }
    
    private native java.lang.Object data_native_cref_QModelIndex_int_constfct(long __this__nativeId, io.qt.core.QModelIndex index, int role);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodelreplica.html#hasData">QAbstractItemModelReplica::hasData(QModelIndex,int)const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean hasData(io.qt.core.QModelIndex index, int role){
        return hasData_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index, role);
    }
    
    @io.qt.QtUninvokable
    private native boolean hasData_native_cref_QModelIndex_int_constfct(long __this__nativeId, io.qt.core.QModelIndex index, int role);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodelreplica.html#isInitialized">QAbstractItemModelReplica::isInitialized()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isInitialized(){
        return isInitialized_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isInitialized_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodelreplica.html#rootCacheSize">QAbstractItemModelReplica::rootCacheSize()const</a></p>
     */
    @io.qt.QtUninvokable
    public final long rootCacheSize(){
        return rootCacheSize_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native long rootCacheSize_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodelreplica.html#selectionModel">QAbstractItemModelReplica::selectionModel()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QItemSelectionModel selectionModel(){
        return selectionModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QItemSelectionModel selectionModel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodelreplica.html#setRootCacheSize">QAbstractItemModelReplica::setRootCacheSize(size_t)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setRootCacheSize(long rootCacheSize){
        setRootCacheSize_native_size_t(QtJambi_LibraryUtilities.internal.nativeId(this), rootCacheSize);
    }
    
    @io.qt.QtUninvokable
    private native void setRootCacheSize_native_size_t(long __this__nativeId, long rootCacheSize);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#columnCount">QAbstractItemModel::columnCount(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public int columnCount(io.qt.core.QModelIndex parent){
        return columnCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), parent);
    }
    
    @io.qt.QtUninvokable
    private native int columnCount_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#flags">QAbstractItemModel::flags(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.Qt.ItemFlags flags(io.qt.core.QModelIndex index){
        return new io.qt.core.Qt.ItemFlags(flags_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index));
    }
    
    @io.qt.QtUninvokable
    private native int flags_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex index);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#hasChildren">QAbstractItemModel::hasChildren(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public boolean hasChildren(io.qt.core.QModelIndex parent){
        return hasChildren_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), parent);
    }
    
    @io.qt.QtUninvokable
    private native boolean hasChildren_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#headerData">QAbstractItemModel::headerData(int,Qt::Orientation,int)const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.Object headerData(int section, io.qt.core.Qt.Orientation orientation, int role){
        return headerData_native_int_Qt_Orientation_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), section, orientation.value(), role);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object headerData_native_int_Qt_Orientation_int_constfct(long __this__nativeId, int section, int orientation, int role);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#index">QAbstractItemModel::index(int,int,QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QModelIndex index(int row, int column, io.qt.core.QModelIndex parent){
        return index_native_int_int_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), row, column, parent);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex index_native_int_int_cref_QModelIndex_constfct(long __this__nativeId, int row, int column, io.qt.core.QModelIndex parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#multiData">QAbstractItemModel::multiData(QModelIndex,QModelRoleDataSpan)const</a></p>
     */
    @io.qt.QtUninvokable
    public void multiData(io.qt.core.QModelIndex index, java.util.Map<Integer,Object> roleDataSpan){
        multiData_native_cref_QModelIndex_QModelRoleDataSpan_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index, roleDataSpan);
    }
    
    @io.qt.QtUninvokable
    private native void multiData_native_cref_QModelIndex_QModelRoleDataSpan_constfct(long __this__nativeId, io.qt.core.QModelIndex index, java.util.Map<Integer,Object> roleDataSpan);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#parent">QAbstractItemModel::parent(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QModelIndex parent(io.qt.core.QModelIndex index){
        return parent_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex parent_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex index);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#roleNames">QAbstractItemModel::roleNames()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.util.Map<java.lang.Integer, io.qt.core.QByteArray> roleNames(){
        return roleNames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.util.Map<java.lang.Integer, io.qt.core.QByteArray> roleNames_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#rowCount">QAbstractItemModel::rowCount(QModelIndex)const</a></p>
     */
    @io.qt.QtUninvokable
    public int rowCount(io.qt.core.QModelIndex parent){
        return rowCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), parent);
    }
    
    @io.qt.QtUninvokable
    private native int rowCount_native_cref_QModelIndex_constfct(long __this__nativeId, io.qt.core.QModelIndex parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractitemmodel.html#setData">QAbstractItemModel::setData(QModelIndex,QVariant,int)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean setData(io.qt.core.QModelIndex index, java.lang.Object value, int role){
        return setData_native_cref_QModelIndex_cref_QVariant_int(QtJambi_LibraryUtilities.internal.nativeId(this), index, value, role);
    }
    
    @io.qt.QtUninvokable
    private native boolean setData_native_cref_QModelIndex_cref_QVariant_int(long __this__nativeId, io.qt.core.QModelIndex index, java.lang.Object value, int role);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractItemModelReplica(QPrivateConstructor p) { super(p); } 
    
}
